@@ -57,9 +57,10 @@ void DocActionPix::Exec(bool bInteractive)
 		dlg.SetTitle(_("Open picture"));
 
 		//define file filters
-		dlg.AddFilter(_("All supported image formats (*.png,*.jpg)"), "*.png|*.jpg");
+		dlg.AddFilter(_("All supported image formats (*.png,*.jpg,*.gif)"), "*.png|*.jpg|*.gif");
 		dlg.AddFilter(_("PNG format (*.png)"), "*.png");
 		dlg.AddFilter(_("JPG format (*.jpg)"), "*.jpg");
+		dlg.AddFilter(_("GIF format (*.gif)"), "*.gif");
 		dlg.AddFilter(_("All files (*)"), "*");
 
 		//set initial directory from INI (store last used)
@@ -125,10 +126,26 @@ void DocActionPix::Exec(bool bInteractive)
 			info.pixbuf  = pixbuf;
 			info.strName = strName;
 			g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures.push_back(info);
+			std::sort(g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures.begin(), g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures.end());
 
 			m_nOffset = cursor;
 			m_pixbuf  = pixbuf;
 			m_bUsePNG = dlg1.m_bUsePNG;
+
+			//increment offsets for all formatting marks
+			int nSize = g_doc.GetNodeByIdx(m_nNodeIdx).m_lstTxtFmt.size();
+			int i;
+			for(i=0; i<nSize; i++){
+				if(g_doc.GetNodeByIdx(m_nNodeIdx).m_lstTxtFmt[i].nOffset >= m_nOffset)
+					g_doc.GetNodeByIdx(m_nNodeIdx).m_lstTxtFmt[i].nOffset ++;
+			}
+
+			//increment all the pictures after this one
+			nSize = g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures.size();
+			for(i=0; i<nSize; i++){
+				if(g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures[i].nOffset > m_nOffset)
+					g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures[i].nOffset ++;
+			}
 		}
 	}
 	else
@@ -141,11 +158,19 @@ void DocActionPix::Exec(bool bInteractive)
 
 		//increment offsets for all formatting marks
 		int nSize = g_doc.GetNodeByIdx(m_nNodeIdx).m_lstTxtFmt.size();
-		for(int i=0; i<nSize; i++){
+		int i;
+		for(i=0; i<nSize; i++){
 			if(g_doc.GetNodeByIdx(m_nNodeIdx).m_lstTxtFmt[i].nOffset >= m_nOffset)
 				g_doc.GetNodeByIdx(m_nNodeIdx).m_lstTxtFmt[i].nOffset ++;
 		}
 
+		//increment all the pictures after this one
+		nSize = g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures.size();
+		for(i=0; i<nSize; i++){
+			if(g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures[i].nOffset > m_nOffset)
+				g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures[i].nOffset ++;
+		}
+
 		if(m_nNodeIdx == GetSelectedNodeIdx()){
 			//get the iterator
 			GtkTextBuffer* buffer1 = gtk_text_view_get_buffer((GtkTextView *)g_text.m_pWidget);
@@ -166,11 +191,19 @@ void DocActionPix::Undo()
 			//decrement offsets for all formatting marks
 			int nOffset = g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures[i].nOffset;
 			int nSize = g_doc.GetNodeByIdx(m_nNodeIdx).m_lstTxtFmt.size();
-			for(int j=0; j<nSize; j++){
+			int j;
+			for(j=0; j<nSize; j++){
 				if(g_doc.GetNodeByIdx(m_nNodeIdx).m_lstTxtFmt[j].nOffset > nOffset)
 					g_doc.GetNodeByIdx(m_nNodeIdx).m_lstTxtFmt[j].nOffset --;
 			}
 
+			//decrement all the pictures after this one
+			nSize = g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures.size();
+			for(j=0; j<nSize; j++){
+				if(g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures[j].nOffset > nOffset)
+					g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures[j].nOffset --;
+			}
+			
 			g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures.erase(g_doc.GetNodeByIdx(m_nNodeIdx).m_lstPictures.begin() + i);
 			break;
 		}
