@@ -11,8 +11,11 @@
 #include "gui/FileDialog.h"
 #include "callbacks.h"
 #include "interface.h"
+#include "lib/NoteDocument.h"
+#include <string.h>
 
 extern GtkWidget *window1;
+extern NoteDocument g_doc;
 
 static void on_pick_file_clicked (GtkMenuItem *menuitem, gpointer user_data);
 static void on_link_remove_clicked (GtkMenuItem *menuitem, gpointer user_data);
@@ -246,7 +249,9 @@ void LinkPropertiesDlg::UpdateData(bool bToScreen)
 				GtkTreeView *treeview = (GtkTreeView *)lookup_widget(window1, "treeview1");
 				GtkTreeModel *model = gtk_tree_view_get_model((GtkTreeView *)treeview);
 				GtkTreePath* path1 = gtk_tree_model_get_path(model, &iter);
-				m_info.m_nTargetNodeID = NodeIdxFromPath(path1);
+				int nNodeIdx = NodeIdxFromPath(path1);
+				if(nNodeIdx >= 0)
+					m_info.m_nTargetNodeID = g_doc.GetNodeByIdx(nNodeIdx).m_nID;
 				gtk_tree_path_free(path1);
 			}
 		}
