@@ -142,8 +142,8 @@ ShortcutsList::ShortcutsList()
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_TREE_NODE_MOVE_LEFT, _("Move Node Left"), 0, false, false, false));
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_TREE_NODE_MOVE_RIGHT, _("Move Node Right"), 0, false, false, false));
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_TREE_NODE_PROPERTIES, _("Show Node Properties"), 0, false, false, false));
-		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_TREE_NODE_DELETE_FINISHED, _("Delete Finished Nodes"), 0, false, false, false));
-		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_TREE_NODE_TOGGLE_FINISHED, _("Toggle Finished Status"), 0, false, false, false));
+		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_TREE_NODE_DELETE_FINISHED, _("Delete Completed Nodes"), 0, false, false, false));
+		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_TREE_NODE_TOGGLE_FINISHED, _("Toggle Completed Status"), 0, false, false, false));
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_TREE_SORT_CHILDREN_ASC, _("Sort Children Ascending"), 0, false, false, false));
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_TREE_SORT_CHILDREN_DESC, _("Sort Children Descending"), 0, false, false, false));
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_TREE_SORT_ROOT_ASC, _("Sort Tree Ascending"), 0, false, false, false));
@@ -183,6 +183,7 @@ ShortcutsList::ShortcutsList()
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_VIEW_WORD_COUNT, _("Calculate Word Count"), 'K', false, true, false));
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_HELP_INDEX, _("Show help"), GDK_F1, false, false, false));
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_HELP_ABOUT, _("About"), 0, false, false, false));
+		g_lstDefAction.push_back(ShortcutDef(SH_CTX_GLOBAL, NC_ACTION_VISIT_WEBSITE, _("Visit Website"), 0, false, false, false));
 
 		//tree only actions
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_TREE_WIDGET, NC_ACTION_TREE_NODE_NEW, _("New Node"), GDK_Insert, false, false, false));
@@ -194,8 +195,8 @@ ShortcutsList::ShortcutsList()
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_TREE_WIDGET, NC_ACTION_TREE_NODE_MOVE_LEFT, _("Move Node Left"), GDK_Left, true, false, false));
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_TREE_WIDGET, NC_ACTION_TREE_NODE_MOVE_RIGHT, _("Move Node Right"), GDK_Right, true, false, false));
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_TREE_WIDGET, NC_ACTION_TREE_NODE_PROPERTIES, _("Show Node Properties"), GDK_Return, false, true, false));
-		g_lstDefAction.push_back(ShortcutDef(SH_CTX_TREE_WIDGET, NC_ACTION_TREE_NODE_DELETE_FINISHED, _("Delete Finished Nodes"), 0, false, false, false));
-		g_lstDefAction.push_back(ShortcutDef(SH_CTX_TREE_WIDGET, NC_ACTION_TREE_NODE_TOGGLE_FINISHED, _("Toggle Finished Status"), ' ', false, false, false));
+		g_lstDefAction.push_back(ShortcutDef(SH_CTX_TREE_WIDGET, NC_ACTION_TREE_NODE_DELETE_FINISHED, _("Delete Completed Nodes"), 0, false, false, false));
+		g_lstDefAction.push_back(ShortcutDef(SH_CTX_TREE_WIDGET, NC_ACTION_TREE_NODE_TOGGLE_FINISHED, _("Toggle Completed Status"), ' ', false, false, false));
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_TREE_WIDGET, NC_ACTION_TREE_SORT_CHILDREN_ASC, _("Sort Children Ascending"), 0, false, false, false));
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_TREE_WIDGET, NC_ACTION_TREE_SORT_CHILDREN_DESC, _("Sort Children Descending"), 0, false, false, false));
 		g_lstDefAction.push_back(ShortcutDef(SH_CTX_TREE_WIDGET, NC_ACTION_TREE_SORT_ROOT_ASC, _("Sort Tree Ascending"), 0, false, false, false));
