@@ -89,6 +89,19 @@ enum NC_Actions {
 	DUMMY_ITEM5,					// keeps IDs sychronized with Pro version
 	DUMMY_ITEM6,					// keeps IDs sychronized with Pro version
 	DUMMY_ITEM7,					// keeps IDs sychronized with Pro version
+	DUMMY_ITEM8,					// keeps IDs sychronized with Pro version
+	DUMMY_ITEM9,					// keeps IDs sychronized with Pro version
+	DUMMY_ITEM10,					// keeps IDs sychronized with Pro version
+	DUMMY_ITEM11,					// keeps IDs sychronized with Pro version
+	DUMMY_ITEM12,					// keeps IDs sychronized with Pro version
+	DUMMY_ITEM13,					// keeps IDs sychronized with Pro version
+	DUMMY_ITEM14,					// keeps IDs sychronized with Pro version
+	DUMMY_ITEM15,					// keeps IDs sychronized with Pro version
+	DUMMY_ITEM16,					// keeps IDs sychronized with Pro version
+	DUMMY_ITEM17,					// keeps IDs sychronized with Pro version
+	DUMMY_ITEM18,					// keeps IDs sychronized with Pro version
+	DUMMY_ITEM19,					// keeps IDs sychronized with Pro version
+	NC_ACTION_VISIT_WEBSITE
 };
 
 //shortcut context
