@@ -424,6 +424,9 @@ bool Open(const std::string& path, const std::string& args)
 		strURI = uri.ToString();
 	}
 
+	if(strURI.empty())
+		strURI = path;
+
 	TRACE("Open path:%s - URI:%s, mime type:%s\n", path.c_str(), strURI.c_str(), mimeType.c_str());
 	if (!mimeType.empty())
 	{
