@@ -8,6 +8,7 @@
 ////////////////////////////////////////////////////////////////////////////
 
 #include "CircularBuffer.h"
+#include "File64.h"
 #include <stdlib.h>
 #include <string.h>
 #include <stdarg.h>
@@ -40,18 +41,22 @@ CircularBuffer::~CircularBuffer()
 		free(m_pszData);
 }
 
-void CircularBuffer::Dump(FILE *pOutFile)
+void CircularBuffer::Dump(const char *szFile)
 {
 	if(IsEmpty())
 		return;
 
+	File64 file;
+	if(!file.Open(szFile, F64_WRITE|F64_OPEN_NEW))
+		return;
+	
 	size_t nWritten;
 	if(m_nEnd > m_nStart){
-		nWritten = fwrite(m_pszData + m_nStart, 1, m_nEnd-m_nStart, pOutFile);
+		nWritten = file.Write(m_pszData + m_nStart, m_nEnd-m_nStart);
 	}
 	else{
-		nWritten = fwrite(m_pszData + m_nStart, 1, m_nSize-m_nStart, pOutFile);
-		nWritten = fwrite(m_pszData, 1, m_nEnd, pOutFile);
+		nWritten = file.Write(m_pszData + m_nStart, m_nSize-m_nStart);
+		nWritten = file.Write(m_pszData, m_nEnd);
 	}
 }
 
