@@ -27,7 +27,7 @@ public:
 	void AddMsg(const char *szMsg);
 	void Add(const char *szMsg);
 	void Printf(const char *fmt, ...);
-	void Dump(FILE *pOutFile);
+	void Dump(const char *szFile);
 
 	bool IsEmpty(){	return (m_nStart == m_nEnd); };
 	int  GetUsedSize(){	return (m_nStart <= m_nEnd) ? (m_nEnd - m_nStart) : (m_nSize - m_nStart + m_nEnd); };
