@@ -11,6 +11,7 @@
 #include <algorithm>
 #include <glib.h>
 #include "debug.h"
+#include <string.h>
 
 extern TextView g_text;
 
@@ -65,64 +66,12 @@ FmtInfoList::~FmtInfoList()
 {
 }
 
-//TOFIX move to FmtInfo?
-bool FmtInfoList::IsStartTag(int nFormatTag)
+void FmtInfoList::operator =(const std::vector<FmtInfo> &other)
 {
-	if( FMT_BOLD_BEGIN == nFormatTag ||
-		FMT_ITALIC_BEGIN == nFormatTag ||
-		FMT_UNDERLINE_BEGIN == nFormatTag ||
-		FMT_TXT_COLOR_BEGIN == nFormatTag ||
-		FMT_STRIKE_BEGIN == nFormatTag ||
-		FMT_TXT_BKG_COLOR_BEGIN == nFormatTag)
-		return true;
-
-	return false;
+	*((std::vector<FmtInfo> *)this) = other;
+	ASSERT(size() == other.size());
 }
 
-int	FmtInfoList::CalcFormatEndTag(int nFormatTag)
-{
-	if(FMT_BOLD_BEGIN == nFormatTag)
-		return FMT_BOLD_END;
-	else if(FMT_ITALIC_BEGIN == nFormatTag)
-		return FMT_ITALIC_END;
-	else if(FMT_UNDERLINE_BEGIN == nFormatTag)
-		return FMT_UNDERLINE_END;
-	else if(FMT_TXT_COLOR_BEGIN == nFormatTag)
-		return FMT_TXT_COLOR_END;
-	else if(FMT_STRIKE_BEGIN == nFormatTag)
-		return FMT_STRIKE_END;
-	else if(FMT_TXT_BKG_COLOR_BEGIN == nFormatTag)
-		return FMT_TXT_BKG_COLOR_END;
-
-	return -1;
-}
-
-int	FmtInfoList::CalcFormatStartTag(int nFormatTag)
-{
-	if(FMT_BOLD_END == nFormatTag)
-		return FMT_BOLD_BEGIN;
-	else if(FMT_ITALIC_END == nFormatTag)
-		return FMT_ITALIC_BEGIN;
-	else if(FMT_UNDERLINE_END == nFormatTag)
-		return FMT_UNDERLINE_BEGIN;
-	else if(FMT_TXT_COLOR_END == nFormatTag)
-		return FMT_TXT_COLOR_BEGIN;
-	else if(FMT_STRIKE_END == nFormatTag)
-		return FMT_STRIKE_BEGIN;
-	else if(FMT_TXT_BKG_COLOR_END == nFormatTag)
-		return FMT_TXT_BKG_COLOR_BEGIN	;
-
-	return -1;
-}
-
-int	FmtInfoList::CalcOppositeTag(int nFormatTag)
-{
-	if(IsStartTag(nFormatTag))
-		return CalcFormatEndTag(nFormatTag);
-	return CalcFormatStartTag(nFormatTag);
-}
-
-
 bool FmtInfoList::IsRangeFormatted(int nStart, int nEnd, int nFormatTag)
 {
 	int nEndTag = CalcFormatEndTag(nFormatTag);
@@ -553,8 +502,8 @@ void FmtInfoList::OnTxtInsert(int nOffset, int nCharsAdded, const char *szTxt)
 		FmtInfo &info = operator[](i);
 
 		//contents added before the tag
-		if((nOffset < info.nOffset) || 
-		   ((nOffset == info.nOffset) && FmtInfoList::IsStartTag(info.nFormatTag)))
+		if((nOffset <= info.nOffset) /*|| 
+		   ((nOffset == info.nOffset) && FmtInfoList::IsStartTag(info.nFormatTag))*/)
 			info.nOffset += nCharsAdded;
 	}
 
