@@ -99,6 +99,11 @@ int FormatIO_HTML::Load(const char *szFile, NoteDocument &doc)
 	//clear old document contents
 	doc.Clear();
 
+	if(m_bNoteCenterMode){
+		m_bAllowUnescapedInPreTag = true;
+		m_bBRTagUsed = false;
+	}
+
 	IOProcess objFile(MODE_READ);
 	
 	// attach file read layer
@@ -446,11 +451,9 @@ void FormatIO_HTML::OnTagBegin(const char *szTag, const char *szParams)
 				gdk_pixbuf_ref (pixbuf); // make sure we keep a reference to it
 				g_object_unref (G_OBJECT (loader));
 
-				int nCnt = m_pDoc->GetNodeByIdx(m_nCurNodeIdx).m_lstPictures.size();
-
 				PixInfo info;
 				info.bUsePNG = bUsePNG;
-				info.nOffset = m_nPicCountInCurNode + g_utf8_strlen(m_pDoc->GetNodeByIdx(m_nCurNodeIdx).GetText().c_str(), -1) + nCnt;
+				info.nOffset = m_nPicCountInCurNode + g_utf8_strlen(m_pDoc->GetNodeByIdx(m_nCurNodeIdx).GetText().c_str(), -1);
 				info.pixbuf  = pixbuf;
 				info.strName = strTitle;
 				m_pDoc->GetNodeByIdx(m_nCurNodeIdx).m_lstPictures.push_back(info);
@@ -1326,6 +1329,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 					const char *szBuf = strTmp.c_str();
 					gchar* pszPos = g_utf8_offset_to_pointer(szBuf, link.m_nStartOffset-nOffsetTot);
 					nPosBuf = pszPos - szBuf;
+					ASSERT(nPosBuf >= 0);
 
 					//erase original segment
 					bool bText = lstSegments[nSegmentIdx].bIsText;
@@ -1452,6 +1456,8 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 				// keep breaking text within the segments list
 				//
 
+				int nPicsBeforeThis = i;
+
 				//find segment for given offset (ignore link segments)
 				int nSegmentIdx = -1;
 				int nOffset = pix.nOffset;		
@@ -1463,7 +1469,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 
 					std::string &strTmp = lstSegments[j].strText;
 					int nSize = g_utf8_strlen(strTmp.c_str(), -1);
-					if(nOffsetTot + nSize > nOffset){
+					if(nOffsetTot + nSize + nPicsBeforeThis > nOffset){
 						nSegmentIdx = j;
 						break;
 					}
@@ -1478,8 +1484,9 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 					//convert character offset to the buffer offset
 					int nPosBuf;
 					const char *szBuf = strTmp.c_str();
-					gchar* pszPos = g_utf8_offset_to_pointer(szBuf, pix.nOffset-nOffsetTot-i); // i -> account for previous images (each taking one byte)
+					gchar* pszPos = g_utf8_offset_to_pointer(szBuf, pix.nOffset-nOffsetTot-nPicsBeforeThis);
 					nPosBuf = pszPos - szBuf;
+					ASSERT(nPosBuf >= 0);
 
 					//erase original segment
 					bool bText = lstSegments[nSegmentIdx].bIsText;
@@ -1672,6 +1679,13 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 			{
 				FmtInfo &fmt = node.m_lstTxtFmt[i];
 
+				int nPicsBeforeThis = 0;
+				for(int k=0; k<nPicsCount; k++)
+					if(node.m_lstPictures[k].nOffset < fmt.nOffset)
+						nPicsBeforeThis ++;
+					else
+						break;
+
 				//
 				// keep breaking text within the segments list
 				//
@@ -1687,7 +1701,7 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 
 					std::string &strTmp = lstSegments[j].strText;
 					int nSize = g_utf8_strlen(strTmp.c_str(), -1);
-					if(nOffsetTot + nSize > nOffset){
+					if(nOffsetTot + nSize + nPicsBeforeThis > nOffset){
 						nSegmentIdx = j;
 						break;
 					}
@@ -1702,8 +1716,9 @@ void FormatIO_HTML::WriteLevel(DocumentIterator &it, IOProcess &file, int nParen
 					//convert character offset to the buffer offset
 					int nPosBuf;
 					const char *szBuf = strTmp.c_str();
-					gchar* pszPos = g_utf8_offset_to_pointer(szBuf, fmt.nOffset-nOffsetTot);
+					gchar* pszPos = g_utf8_offset_to_pointer(szBuf, fmt.nOffset-nOffsetTot-nPicsBeforeThis);
 					nPosBuf = pszPos - szBuf;
+					ASSERT(nPosBuf >= 0);
 
 					//erase original segment
 					bool bText = lstSegments[nSegmentIdx].bIsText;
