@@ -15,7 +15,7 @@ class FormatIO_MMLX : public FormatIO_Base
 {
 public:
 	FormatIO_MMLX();
-	~FormatIO_MMLX();
+	virtual ~FormatIO_MMLX();
 
 	virtual int Load(const char *szFile, NoteDocument &doc);
 	virtual int Save(const char *szFile, NoteDocument &doc);
