@@ -15,7 +15,7 @@ class FormatIO_Txt : public FormatIO_Base
 {
 public:
 	FormatIO_Txt();
-	~FormatIO_Txt();
+	virtual ~FormatIO_Txt();
 
 	virtual int Load(const char *szFile, NoteDocument &doc);
 	virtual int Save(const char *szFile, NoteDocument &doc);
